@@ -17,6 +17,9 @@ hidden_imports = [
     "ics.structures.st_chip_versions",
     "ics.structures.s_neo_most_gateway_settings",
     "ics.structures.op_eth_general_settings",
+    "ics.structures.srad_gptp_settings_s",
+    "ics.structures.srad_gptp_and_tap_settings_s",
+    "ics.structures.hw_eth_settings",
     "ics.structures.op_eth_settings",
     "ics.structures.ethernet_settings",
     "ics.structures.ethernet_settings2",
@@ -52,6 +55,7 @@ hidden_imports = [
     "ics.structures.srad_galaxy_settings",
     "ics.structures.srad_star2_settings",
     "ics.structures.srad_super_moon_settings",
+    "ics.structures.a2_b_monitor_settings",
     "ics.structures.srada2_b_settings",
     "ics.structures.srad_moon2_settings",
     "ics.structures.srad_gigalog_settings",
@@ -81,6 +85,7 @@ hidden_imports = [
     "ics.structures.s_pluto_custom_params_s",
     "ics.structures.s_pluto_switch_settings_s",
     "ics.structures.srad_pluto_settings",
+    "ics.structures.scan_sleep_id",
     "ics.structures.scan_hub_settings",
     "ics.structures.s_flex_vnetz_settings",
     "ics.structures.s_neo_ecu12_settings",
@@ -111,7 +116,7 @@ hidden_imports = [
     "ics.structures.ics_rad_pluto_device_status",
     "ics.structures.ics_vcan4_industrial_device_status",
     "ics.structures.ics_device_status",
-    "ics.structures.j2534_adapter_information",
+    "ics.structures.ndis_adapter_information",
     "ics.structures.s_phy_reg_pkt_hdr",
     "ics.structures.s_phy_reg_pkt_clause22_mess",
     "ics.structures.s_phy_reg_pkt_clause45_mess",
@@ -120,6 +125,9 @@ hidden_imports = [
     "ics.structures.e_disk_format",
     "ics.structures.e_disk_layout",
     "ics.structures.extended_response_code",
+    "ics.structures.e_gptp_port",
+    "ics.structures.e_gptp_role",
+    "ics.structures.a2_btdm_mode",
     "ics.structures.flex_vnet_mode",
     "ics.structures.e_device_settings_type",
     "ics.structures.e_plasma_ion_vnet_channel_t",
